Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2326)

Unified Diff: ash/wm/activation_controller.cc

Issue 13896026: Stick windows to sides of workspaces (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Dock with zero width (comments on unit tests) Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/activation_controller.cc
diff --git a/ash/wm/activation_controller.cc b/ash/wm/activation_controller.cc
index 8c48346b5eb313e3b87f80cd7956829740eb952e..885ad6c1fe196527fafbc1a45208ed76a2f124fc 100644
--- a/ash/wm/activation_controller.cc
+++ b/ash/wm/activation_controller.cc
@@ -39,9 +39,10 @@ const int kWindowContainerIds[] = {
kShellWindowId_AppListContainer,
kShellWindowId_DefaultContainer,
// Panel, launcher and status are intentionally checked after other
// containers even though these layers are higher. The user expects their
// windows to be focused before these elements.
+ kShellWindowId_DockedContainer,
kShellWindowId_PanelContainer,
kShellWindowId_ShelfContainer,
kShellWindowId_StatusContainer,
@@ -39,9 +39,10 @@ const int kWindowContainerIds[] = {
kShellWindowId_AppListContainer,
kShellWindowId_DefaultContainer,
- // Panel, launcher and status are intentionally checked after other
+ // Docked, panel, launcher and status are intentionally checked after other
// containers even though these layers are higher. The user expects their
// windows to be focused before these elements.

Powered by Google App Engine
This is Rietveld 408576698